@@ -134,6 +134,7 @@
 ##' @param ... Other graphical parameters passed onto \code{lattice:xyplot}
 ##'   and \code{cutData}. For example, in the case of \code{cutData} the option
 ##'   \code{hemisphere = "southern"}.
+##' @import lattice
 ##' @export
 ##' @return As well as generating the plot itself, \code{timeVariation} also
 ##'   returns an object of class ``openair''. The object includes three main
@@ -304,7 +305,7 @@ alpha = 0.4, ...)  {
     ## if group is present, need to add that list of variables
     if (!missing(group)){
 
-        if (group %in%  openair:::dateTypes) {
+        if (group %in%  dateTypes) {
             vars <- unique(c(vars, "date"))
         } else {
             vars <- unique(c(vars, group))
@@ -312,7 +313,7 @@ alpha = 0.4, ...)  {
     }
 
     ## data checks
-    mydata <- openair:::checkPrep(mydata, vars, type, remove.calm = FALSE)
+    mydata <- checkPrep(mydata, vars, type, remove.calm = FALSE)
     if (!missing(group))  mydata <- cutData(mydata, group, ...)
     mydata <- cutData(mydata, type, ...)
 
@@ -478,13 +479,14 @@ alpha = 0.4, ...)  {
 
                             panel.xyplot(x, y, type = "l", col.line = myColors[group.number],...)
 
-                            if (ci) {openair:::poly.na(x, data.hour$Lower[subscripts], x,
-                                             data.hour$Upper[subscripts], group.number, myColors)}
+                            if (ci) {poly.na(x, data.hour$Lower[subscripts], x,
+                                             data.hour$Upper[subscripts], group.number, myColors,
+                                             alpha = alpha)}
 
                         })
 
     ## reset for extra.args
-    xyplot.args <- openair:::listUpdate(xyplot.args, extra.args)
+    xyplot.args <- listUpdate(xyplot.args, extra.args)
 
     ## plot
     hour <- do.call(xyplot, xyplot.args)
@@ -542,7 +544,7 @@ alpha = 0.4, ...)  {
                         })
 
     ## reset for extra.args
-    xyplot.args <- openair:::listUpdate(xyplot.args, extra.args)
+    xyplot.args <- listUpdate(xyplot.args, extra.args)
 
     ## plot
     day <- do.call(xyplot, xyplot.args)
@@ -599,7 +601,7 @@ alpha = 0.4, ...)  {
                         })
 
     ## reset for extra.args
-    xyplot.args <- openair:::listUpdate(xyplot.args, extra.args)
+    xyplot.args <- listUpdate(xyplot.args, extra.args)
 
     ## plot
     month <- do.call(xyplot, xyplot.args)
@@ -630,7 +632,7 @@ alpha = 0.4, ...)  {
 
     if (type == "default") {
         strip.left <- FALSE
-        layout <- c(7, 1)
+        layout <- c(length(unique(mydata$wkday)), 1)
 
     } else { ## two conditioning variables
 
@@ -676,12 +678,13 @@ alpha = 0.4, ...)  {
 
                             panel.xyplot(x, y, type = "l", col.line = myColors[group.number],...)
 
-                            if (ci) {openair:::poly.na(x, data.day.hour$Lower[subscripts], x,
-                                             data.day.hour$Upper[subscripts], group.number, myColors)}
+                            if (ci) {poly.na(x, data.day.hour$Lower[subscripts], x,
+                                             data.day.hour$Upper[subscripts], group.number, myColors,
+                                             alpha = alpha)}
                         })
 
     ## reset for extra.args
-    xyplot.args <- openair:::listUpdate(xyplot.args, extra.args)
+    xyplot.args <- listUpdate(xyplot.args, extra.args)
 
     ## plot
     day.hour <- do.call(xyplot, xyplot.args)
@@ -754,13 +757,13 @@ calc.wd <- function(mydata, vars = "day.hour", pollutant, type, B = B) {
     ## function to calculate statistics dealing with wd properly
     if (any(!pollutant %in% "wd")) {
         data1 <- subset(mydata, variable != "wd")
-        data1 <-  summary.values(data1, vars, openair:::bootMean, type, B = B)
+        data1 <-  summary.values(data1, vars, bootMean, type, B = B)
         data1 <- data.frame(subset(data1, select = -value), data1$value)
     }
 
     if ("wd" %in% pollutant) {
         data2 <-  subset(mydata, variable == "wd")
-        data2 <-  summary.values(data2, vars, openair:::bootMean, type, B = B)
+        data2 <-  summary.values(data2, vars, bootMean, type, B = B)
         data2 <- data.frame(subset(data2, select = -value), data2$value)
     }
 
@@ -791,7 +794,7 @@ wd.smean.normal <- function(wd, B = B) {
     ids <- which(wd.diff > 180)
     wd.diff[ids] <- abs(wd.diff[ids] - 360)
 
-    conf.int <- openair:::bootMean(wd.diff, B = B)
+    conf.int <- bootMean(wd.diff, B = B)
     Lower <- conf.int[2]
     names(Lower) <- NULL
 
@@ -812,7 +815,7 @@ errorDiff <- function(mydata, vars = "day.hour", poll1, poll2, type, B = B)
     if (vars == "wkday") splits <- c("wkday", type)
     if (vars == "mnth") splits <- c("mnth", type)
 
-    res <- ddply(mydata, splits, openair:::bootMeanDiff, x = poll1, y = poll2, B = B)
+    res <- ddply(mydata, splits, bootMeanDiff, x = poll1, y = poll2, B = B)
 
     res
 }
